Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_stack.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_stack.hh')
-rw-r--r--source/blender/blenlib/BLI_stack.hh10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/blenlib/BLI_stack.hh b/source/blender/blenlib/BLI_stack.hh
index 4645535876d..81b8b192efd 100644
--- a/source/blender/blenlib/BLI_stack.hh
+++ b/source/blender/blenlib/BLI_stack.hh
@@ -20,7 +20,7 @@
/** \file
* \ingroup bli
*
* A `BLI::Stack<T>` is a dynamically growing FILO (first-in, last-out) data structure. It is
* designed to be a more convenient and efficient replacement for `std::stack`.
*
* The improved efficiency is mainly achieved by supporting small buffer optimization. As long as
@@ -34,8 +34,8 @@
* when it grows. This stack implementation does not have to copy all previously pushed elements
* when it grows.
*
* BLI::Stack is implemented using a double linked list of chunks. Each chunk contains an array of
* elements. The chunk size increases exponentially with every new chunk that is required. The
* lowest chunk, i.e. the one that is used for the first few pushed elements, is embedded into the
* stack.
*/
@@ -44,7 +44,7 @@
#include "BLI_array_ref.hh"
#include "BLI_memory_utils.hh"
-namespace BLI {
+namespace blender {
/**
* A StackChunk references a contiguous memory buffer. Multiple StackChunk instances are linked in
@@ -385,6 +385,6 @@ class Stack {
}
};
-} /* namespace BLI */
+} /* namespace blender */
#endif /* __BLI_STACK_HH__ */
@@ -20,7 +20,7 @@
* \ingroup bli
*
- * A `BLI::Stack<T>` is a dynamically growing FILO (first-in, last-out) data structure. It is
+ * A `blender::Stack<T>` is a dynamically growing FILO (first-in, last-out) data structure. It is
* designed to be a more convenient and efficient replacement for `std::stack`.
*
@@ -34,8 +34,8 @@
* when it grows.
*
- * BLI::Stack is implemented using a double linked list of chunks. Each chunk contains an array of
- * elements. The chunk size increases exponentially with every new chunk that is required. The
+ * blender::Stack is implemented using a double linked list of chunks. Each chunk contains an array
+ * of elements. The chunk size increases exponentially with every new chunk that is required. The
* lowest chunk, i.e. the one that is used for the first few pushed elements, is embedded into the
* stack.